@@ -7,4 +7,7 @@ class UsersConfig(AppConfig):
     verbose_name = _("Users")
 
     def ready(self):
-        super(UsersConfig, self).ready()
+        try:
+            from . import signals  # noqa F401
+        except ImportError:
+            pass
