@@ -38,5 +38,7 @@ def set_language_from_url(request, user_language):
     _url = parsed.path
     if len(_url) > 1:
         _url = '/{}/'.format(user_language) + _url.lstrip('/{}/'.format(prev_lang))
+    else:
+        _url = '/'
 
     return redirect(_url)
