@@ -140,9 +140,7 @@ THIRD_PARTY_APPS = [
     "django_celery_beat",
     "django_celery_results",
 
-    "rpc4django",
-
-    "drf_yasg",
+    "drf_spectacular",
 
     "django_project_backup"
 ]
@@ -462,6 +460,8 @@ REST_FRAMEWORK = {
         "rest_framework.renderers.JSONRenderer",
         "rest_framework.renderers.BrowsableAPIRenderer",
     ),
+
+    "DEFAULT_SCHEMA_CLASS": "drf_spectacular.openapi.AutoSchema",
 }
 # Your stuff...
 # ------------------------------------------------------------------------------
