@@ -9,10 +9,10 @@ from django.contrib.flatpages.views import flatpage
 from django.views.i18n import JavaScriptCatalog
 from django.conf import settings
 from django.conf.urls.i18n import i18n_patterns
-from django.utils.translation import gettext_lazy as _
 from django.contrib.auth.decorators import login_required
-# rpc
-from rpc4django.views import serve_rpc_request
+
+from drf_spectacular.views import SpectacularAPIView, SpectacularSwaggerView
+
 # sitemap
 from django.contrib.sitemaps.views import sitemap
 from django.contrib.flatpages.sitemaps import FlatPageSitemap
@@ -23,8 +23,9 @@ from ..urls import (urlpatterns as django_sso_app__urlpatterns,
                     i18n_urlpatterns as django_sso_app_i18n_urlpatterns)
 
 from ..backend.views import set_language_from_url
-from ..backend.api.views import StatsView, schema_view
+from ..backend.api.views import StatsView
 from ..backend.pages.views import HomeView
+from .. import dist_name
 
 
 last_modified_date = timezone.now()
@@ -111,8 +112,6 @@ if settings.DEBUG:
 api_urlpatterns += [
     url(r'^api/v1/_stats/$', StatsView.as_view(), name='stats'),
 
-    url(r'^rpc/v2/$', serve_rpc_request),
-
     # your api here
 ]
 
@@ -124,9 +123,12 @@ if len(extra_api_urlpatterns):
 urlpatterns += api_urlpatterns
 
 urlpatterns += [
-    url(r'^api/v1/$', schema_view.with_ui('swagger', cache_timeout=0), name='schema-swagger-ui'),
-    url(r'^api/v1/(?P<format>\.json|\.yaml)$', schema_view.without_ui(cache_timeout=0), name='schema-json'),
-    # url(r'^api/v1/redoc/$', schema_view.with_ui('redoc', cache_timeout=0), name='schema-redoc'),
+    path(
+        "api/v1/",
+        SpectacularSwaggerView.as_view(url_name="api-schema"),
+        name="api-docs",
+    ),
+    path("api/v1/schema/", SpectacularAPIView.as_view(), name="api-schema"),
 ]
 
 # extra
