@@ -1,7 +1,7 @@
 import logging
 
 from django.db import models
-from django.contrib.auth.models import Group as DjangoGroup
+from django.contrib.auth.models import Group
 from django.utils.translation import ugettext_lazy as _
 from django.urls import reverse
 
@@ -12,6 +12,7 @@ from ...models import CreatedAtModel
 logger = logging.getLogger('django_sso_app.core.apps.groups')
 
 
+"""
 class Group(DjangoGroup):
     class Meta:
         proxy = True
@@ -20,6 +21,7 @@ class Group(DjangoGroup):
 
     def get_relative_rest_url(self):
         return reverse("django_sso_app_group:rest-detail", args=[self.pk])
+"""
 
 
 class GroupingManager(MP_NodeManager):
