@@ -187,7 +187,7 @@ class SignupView(allauth_account_views.SignupView, DjangoSsoAppViewMixin, Webpac
 
         else:
             # log signup failed
-            if response.status_code not in [200, 302]:
+            if response.status_code not in (200, 302):
                 if hasattr(response, 'render'):
                     response.render()
                 logger.warning('User failed to register: "{}"'.format(response.content))
